package ru.myitschool.work.ui.result

import android.os.Bundle
import android.util.Log
import android.view.View
import android.widget.Toast
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import dagger.hilt.android.AndroidEntryPoint
import ru.myitschool.work.R
import androidx.navigation.fragment.findNavController
import androidx.transition.Visibility
import ru.myitschool.work.databinding.FragmentScanResultBinding
import ru.myitschool.work.ui.login.LoginViewModel
import ru.myitschool.work.ui.main.MainDestination
import ru.myitschool.work.utils.AuthPreferences
import ru.myitschool.work.utils.collectWhenStarted
import ru.myitschool.work.utils.visibleOrGone

@AndroidEntryPoint
class ResultFragment : Fragment(R.layout.fragment_scan_result) {
    private var _binding: FragmentScanResultBinding? = null
    private val binding: FragmentScanResultBinding get() = _binding!!
    private val viewModel: ResultViewModel by viewModels()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        _binding = FragmentScanResultBinding.bind(view)

        setupLoginComponents()
    }

    private fun setupLoginComponents() {
        binding.apply {
            result.visibleOrGone(false)
            successIcon.visibleOrGone(false)
        }
    }

    private fun observeLoginState() {
        viewModel.state.collectWhenStarted(this) { state ->
            when (state) {
                is ResultViewModel.ResultState.Loading -> {
                    binding.result.visibleOrGone(false)
                    binding.successIcon.visibleOrGone(false)
                    binding.error.visibleOrGone(false)

                    binding.loading.visibleOrGone(true)
                }
                is ResultViewModel.ResultState.Success -> {
                    binding.result.visibleOrGone(true)
                    binding.successIcon.visibleOrGone(true)

                    binding.error.visibleOrGone(false)
                    binding.loading.visibleOrGone(false)
                }
                is ResultViewModel.ResultState.InvalidCredentials -> {
                    binding.result.visibleOrGone(false)
                    binding.successIcon.visibleOrGone(false)
                    binding.loading.visibleOrGone(false)

                    binding.error.visibleOrGone(true)
                }
                is ResultViewModel.ResultState.Error -> {
                    binding.loading.visibleOrGone(false)
                    binding.result.apply {
                        visibleOrGone(true)
                        text = RiootoString(R.string.userNotFing)
                    }
                    Log.d("Authentication", "Ошибка сканирования")
                }

                LoginViewModel.LoginState.Initial -> binding.loading.visibleOrGone(false)
            }
        }
    }

    private fun navigateToMainScreen() {
        try {
            findNavController().apply {
                popBackStack(MainDestination, false)
                navigate(MainDestination)
            }
        } catch (e: Exception) {
            Log.e("ResultFragment", "Navigation error", e)
            Toast.makeText(context, "Ошибка перехода", Toast.LENGTH_SHORT).show()
        }
    }

    override fun onDestroyView() {
        _binding = null
        super.onDestroyView()
    }
}